svn commit: r15382 - trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: tfmorris
Date: 2008-07-27 22:54:00-0700
New Revision: 15382

Modified:
   trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java

Log:
Issue 4994: Javadoc updates.  No functional change.

Modified: trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java?view=diff&rev=15382&p1=trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java&p2=trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java&r1=15381&r2=15382
==============================================================================
--- trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java	(original)
+++ trunk/src/argouml-core-model/src/org/argouml/model/XmiReader.java	2008-07-27 22:54:00-0700
@@ -45,6 +45,8 @@
     
     /**
      * Parse a given inputsource to a collection of top level model elements.
+     * All model elements will be modifiable (ie equivalent to parse(InputSource,
+     * false).
      * 
      * @param pIs the input source for parsing
      * @return a collection of top level elements
@@ -60,16 +62,15 @@
      * 
      * @param pIs
      *            the input source for parsing
      * @param profile
      *            true if the resulting model will be used as a profile.
      *            Profiles are read-only and will not be written back out when
      *            the model data is written.
      * @return a collection of top level elements
      * @throws UmlException
      *             on any error
      * @since 0.22
      */
-    Collection parse(InputSource pIs, boolean profile) throws UmlException;
+    Collection parse(InputSource pIs, boolean readOnly) throws UmlException;
 
     
     /**
@@ -60,16 +62,15 @@
      * @param pIs
      *            the input source for parsing
-     * @param profile
-     *            true if the resulting model will be used as a profile.
-     *            Profiles are read-only and will not be written back out when
-     *            the model data is written.
+     * @param readOnly
+     *            true if the resulting model is to be treated as read-only.
+     *            It not be written back out when the model data is written.
      * @return a collection of top level elements
      * @throws UmlException
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.